@@ -1,9 +1,9 @@
 /*
  * i18n.c -
- * $Id: i18n.c,v 1.24 2000/03/06 08:56:55 rug Exp $
+ * $Id: i18n.c,v 1.26 2001/06/21 06:21:32 rug Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -43,6 +43,7 @@
  */
 
 static const char *guess_category_value ( const char *categoryname );
+static char *get_lang_by_category ( const char *categoryname );
 
 
 /* The following is (partly) taken from the gettext package.
@@ -51,34 +52,48 @@ static const char *guess_category_value ( const char *categoryname );
 static const char *
 guess_category_value (const char *categoryname)
 {
-  const char *retval;
+    const char *retval;
 
-  /* The highest priority value is the `LANGUAGE' environment
-     variable.  This is a GNU extension.  */
-  retval = getenv ("LANGUAGE");
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+    if (!strcmp(categoryname, "LC_MESSAGES")) {
 
-  /* `LANGUAGE' is not set.  So we have to proceed with the POSIX
-     methods of looking to `LC_ALL', `LC_xxx', and `LANG'.  On some
-     systems this can be done by the `setlocale' function itself.  */
+	/* The highest priority value is the `LANGUAGE' environment
+	   variable.  This is a GNU extension.  */
+	retval = getenv ("LANGUAGE");
+	if (retval != NULL && retval[0] != '\0')
+	    return retval;
+    }
 
-  /* Setting of LC_ALL overwrites all other.  */
-  retval = getenv ("LC_ALL");  
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+    /* `LANGUAGE' is not set.  So we have to proceed with the POSIX
+       methods of looking to `LC_ALL', `LC_xxx', and `LANG'.  On some
+       systems this can be done by the `setlocale' function itself.  */
 
-  /* Next comes the name of the desired category.  */
-  retval = getenv (categoryname);
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+    /* Setting of LC_ALL overwrites all other.  */
+    retval = getenv ("LC_ALL");  
+    if (retval != NULL && retval[0] != '\0')
+	return retval;
 
-  /* Last possibility is the LANG environment variable.  */
-  retval = getenv ("LANG");
-  if (retval != NULL && retval[0] != '\0')
-    return retval;
+    /* Next comes the name of the desired category.  */
+    retval = getenv (categoryname);
+    if (retval != NULL && retval[0] != '\0')
+	return retval;
 
-  return NULL;
+    /* Last possibility is the LANG environment variable.  */
+    retval = getenv ("LANG");
+    if (retval != NULL && retval[0] != '\0')
+	return retval;
+
+    return NULL;
+}
+
+static char *
+get_lang_by_category(const char *categoryname) 
+{
+    char *lang;
+    lang = (char *)guess_category_value(categoryname);
+    if (lang == NULL)
+	return "C";
+    else
+	return lang;
 }
 
 /*
@@ -121,14 +136,15 @@ nmz_set_lang(const char *lang)
 }
 
 char *
-nmz_get_lang(void) 
+nmz_get_lang(void)
 {
-    char *lang;
-    lang = (char *)guess_category_value("LC_MESSAGES");
-    if (lang == NULL)
-	return "C";
-    else
-	return lang;
+    return get_lang_by_category("LC_MESSAGES");
+}
+
+char *
+nmz_get_lang_ctype(void)
+{
+    return get_lang_by_category("LC_CTYPE");
 }
 
 /*
