@@ -1,6 +1,6 @@
 /*
  * 
- * $Id: search.c,v 1.74 2000/04/05 07:07:54 satoru Exp $
+ * $Id: search.c,v 1.86 2001/03/11 16:02:45 furukawa Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -38,6 +38,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 #if defined (HAVE_UNISTD_H)
 #include <unistd.h>
 #else
@@ -59,10 +62,10 @@
 #include "seed.h"
 #include "idxname.h"
 #include "query.h"
+#include "score.h"
 
 enum nmz_perm { ALLOW, DENY };
 static int cur_idxnum = -1;
-static int tfidfmode  = 1;
 
 /*
  *
@@ -178,7 +181,7 @@ prefix_match(const char *key, int v)
 	 * Return if too much word would be hit
          * because treat 'a*' completely is too consuming 
 	 */
-	if (j > IGNORE_MATCH) {
+	if (j > nmz_get_maxmatch()) {
 	    nmz_free_hlist(val);
 	    val.stat = ERR_TOO_MUCH_MATCH;
 	    break;
@@ -192,7 +195,7 @@ prefix_match(const char *key, int v)
 	    tmp = nmz_get_hlist(i);
 	    if (tmp.stat == ERR_FATAL)
 	        return tmp;
-	    if (tmp.num > IGNORE_HIT) {
+	    if (tmp.num > nmz_get_maxhit()) {
 		nmz_free_hlist(val);
 		val.stat = ERR_TOO_MUCH_MATCH;
 		break;
@@ -200,7 +203,7 @@ prefix_match(const char *key, int v)
 	    val = nmz_ormerge(val, tmp);
 	    if (val.stat == ERR_FATAL)
 	        return val;
-	    if (val.num > IGNORE_HIT) {
+	    if (val.num > nmz_get_maxhit()) {
 		nmz_free_hlist(val);
 		val.stat = ERR_TOO_MUCH_MATCH;
 		break;
@@ -382,7 +385,7 @@ open_phrase_index_files(FILE **phrase, FILE **phrase_index)
 static NmzResult 
 do_phrase_search(const char *key, NmzResult val)
 {
-    int i, h = 0, ignore = 0;
+    int i, h = 0;
     char *p, tmpkey[BUFSIZE], *words[QUERY_TOKEN_MAX + 1], *prevword = NULL;
     FILE *phrase, *phrase_index;
     struct nmz_hitnumlist *pr_hitnum = NULL; /* phrase hitnum */
@@ -439,13 +442,7 @@ do_phrase_search(const char *key, NmzResult val)
 	} else if (val.num == 0) { /* phrase search is failed halfway */
 	    continue;
 	} else {
-	    if (tmp.stat == ERR_TOO_MUCH_HIT || 
-		val.stat == ERR_TOO_MUCH_HIT) {
-		ignore = 1;
-	    } else {
-		ignore = 0;
-	    }
-	    val = nmz_andmerge(val, tmp, &ignore);
+	    val = nmz_andmerge(val, tmp, 0);
 
 	    strcpy(word_mix, prevword);
 	    strcat(word_mix, word);
@@ -698,25 +695,25 @@ check_access(void)
 static enum nmz_stat
 open_index_files(void)
 {
+    Nmz.wi = fopen(NMZ.wi, "rb"); /* Check NMZ.wi at first to recognize index format */
+    if (Nmz.wi == NULL) {
+        nmz_debug_printf("%s: %s", NMZ.wi, strerror(errno));
+	return ERR_OLD_INDEX_FORMAT;
+    }
     Nmz.i = fopen(NMZ.i, "rb");
     if (Nmz.i == NULL) {
         nmz_debug_printf("%s: %s", NMZ.i, strerror(errno));
-	return FAILURE;
+	return ERR_CANNOT_OPEN_INDEX;
     }
     Nmz.ii = fopen(NMZ.ii, "rb");
     if (Nmz.ii == NULL) {
         nmz_debug_printf("%s: %s", NMZ.ii, strerror(errno));
-	return FAILURE;
+	return ERR_CANNOT_OPEN_INDEX;
     }
     Nmz.w = fopen(NMZ.w, "rb");
     if (Nmz.w == NULL) {
         nmz_debug_printf("%s: %s", NMZ.w, strerror(errno));
-	return FAILURE;
-    }
-    Nmz.wi = fopen(NMZ.wi, "rb");
-    if (Nmz.wi == NULL) {
-        nmz_debug_printf("%s: %s", NMZ.wi, strerror(errno));
-	return FAILURE;
+	return ERR_CANNOT_OPEN_INDEX;
     }
 
     return SUCCESS;
@@ -769,6 +766,7 @@ do_logging(const char *query, int n)
 static NmzResult 
 nmz_search_sub(NmzResult hlist, const char *query, int n)
 {
+    enum nmz_stat nstat;
     cur_idxnum = n;
 
     if (check_access() != ALLOW) { /* if access denied */
@@ -781,9 +779,9 @@ nmz_search_sub(NmzResult hlist, const char *query, int n)
 	return hlist;
     }
 
-    if (open_index_files() != SUCCESS) {
+    if ((nstat = open_index_files()) != SUCCESS) {
         /* If open failed */
-        hlist.stat = ERR_CANNOT_OPEN_INDEX;
+	hlist.stat = nstat;
         return hlist;
     }
 
@@ -834,7 +832,7 @@ make_fullpathname_index(int n)
 static 
 void remove_quotes(char *str) 
 {
-    if (strlen(str) >= 3 && (*str == '"' && str[strlen(str) - 1] == '"') 
+    if ((strlen(str) >= 3 && (*str == '"' && str[strlen(str) - 1] == '"'))
 	|| (*str == '{' && str[strlen(str) - 1] == '}')) 
     {
 	strcpy(str, str + 1); 
@@ -1002,6 +1000,9 @@ nmz_search(const char *query)
 
     hlist = nmz_merge_hlist(tmp);
 
+    /* score recomputation */
+    nmz_recompute_score(&hlist);
+
     if (hlist.stat == SUCCESS && hlist.num > 0) { /* HIT!! */
 	/* Sort by date at first*/
         if (nmz_sort_hlist(hlist, SORT_BY_DATE) != SUCCESS) {
@@ -1101,15 +1102,3 @@ nmz_free_hitnums(struct nmz_hitnumlist *hn)
     }
 }
 
-void
-nmz_set_tfidfmode(int mode)
-{
-    tfidfmode = mode;
-}
-
-int
-nmz_is_tfidfmode(void)
-{
-    return tfidfmode;
-}
-
