@@ -7,7 +7,7 @@ package conf;  # Don't remove this line!
 #
 # Administrator's email address
 #
-$ADDRESS = 'webmaster@amarok.aist-nara.ac.jp';
+$ADDRESS = 'webmaster@kili.eal.or.jp';
 
 
 #===================================================================
@@ -28,9 +28,10 @@ $HTML_SUFFIX = "html?|[ps]html|html\\.[a-z]{2}";
 #
 $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 		"|.*\\.gz|.*\\.Z|.*\\.bz2" .       # Compressed files
-		"|.*\\.pdf" . 			   # PDF
-		"|.*\\.tex" .   		   # TeX
-		"|.*\\.doc|.*\\.xls" .		   # Word, Excel
+		"|.*\\.pdf|.*\\.ps" . 		   # PDF, PostScript
+		"|.*\\.tex|.*\\.dvi" .   	   # TeX, DVI
+		"|.*\\.rpm|.*\\.deb" .   	   # RPM, DEB
+		"|.*\\.doc|.*\\.xls|.*\\.ppt" .	   # Word, Excel, PowerPoint
 		"|.*\\.j[sab]w" .                  # Ichitaro 4, 5, 6
 		"|\\d+|[-\\w]+\\.[1-9n]";          # Mail/News, man
 
@@ -182,12 +183,12 @@ $KAKASI = "module_kakasi -ieuc -oeuc -w";
 #
 # ChaSen 1.51 or later (simple wakatigaki)
 #
-$CHASEN = "no -j -F '\%m '";
+$CHASEN = "module_chasen -j -F '\%m '";
 
 #
 # ChaSen 1.51 or later (with noun words extraction)
 #
-$CHASEN_NOUN = "no -j -F '\%m %H\\n'";
+$CHASEN_NOUN = "module_chasen -j -F '\%m %H\\n'";
 
 #
 # Default Japanese processer: KAKASI or ChaSen.
