@@ -2,7 +2,7 @@
  * 
  * form.c -
  * 
- * $Id: form.c,v 1.56 2000/04/04 22:22:40 kenzo- Exp $
+ * $Id: form.c,v 1.60.4.1 2001/07/04 09:58:06 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -35,6 +35,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 #include "namazu.h"
 #include "libnamazu.h"
 #include "util.h"
@@ -173,7 +176,9 @@ select_option(char *s, const char *name, const char *subquery)
     char value[BUFSIZE];
 
     if (cmp_element(s, (char *)"option") == 0) {
-        delete_str(s, (char *)"selected ");
+	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
+            delete_str(s, (char *)"selected ");
+	}
         fputs(s, stdout);
         get_value(s, value);
         if (strcasecmp(name, "result") == 0) {
@@ -256,7 +261,9 @@ check_checkbox(char *str)
         char *pp;
         int db_count, searched;
 
-        delete_str(str, (char *)"checked");
+	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
+            delete_str(str, (char *)"checked");
+	}
         fputs(str, stdout);
         get_value(str, value);
         for (pp = value, db_count = searched = 0 ; *pp ;db_count++) {
@@ -317,6 +324,7 @@ read_headfoot(const char *fname)
 {
     char *buf, *p, tmpfname[BUFSIZE], suffix[BUFSIZE];
     char *script_name;
+    char *document_name;
 
     if (nmz_choose_msgfile_suffix(fname, suffix) != SUCCESS) {
 	nmz_warn_printf("%s: %s", fname, strerror(errno));
@@ -344,16 +352,26 @@ read_headfoot(const char *fname)
     }
 
     script_name= getenv("SCRIPT_NAME");
+    document_name= getenv("DOCUMENT_NAME");
 
     /* Can't determine script_name */
     if (script_name == NULL) {
 	return buf;
     }
 
+    /* no document_name, set it to script_name */
+    if (document_name == NULL) {
+	document_name = script_name;
+    }
+
     /* Replace {cgi} with a proper namazu.cgi location */
     while ((p = strstr(buf, "{cgi}")) != NULL) {
 	subst(p, "{cgi}", script_name);
     }
+    /* Replace {doc} with the name of the calling document eg, using SSI */
+    while ((p = strstr(buf, "{doc}")) != NULL) {
+	subst(p, "{doc}", document_name);
+    }
 
     return buf;
 }
