@@ -2,7 +2,7 @@
  * 
  * namazu.c - search client of Namazu
  *
- * $Id: namazu-cmd.c,v 1.11 2000/03/03 03:36:21 satoru Exp $
+ * $Id: namazu-cmd.c,v 1.17 2001/01/20 03:34:50 baba Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -41,6 +41,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 #include "namazu.h"
 #include "libnamazu.h"
 #include "getopt.h"
@@ -59,6 +62,12 @@
 #include "system.h"
 #include "namazu.h"
 
+/*
+ * Extern variables.
+ */
+
+extern char contenttype[BUFSIZE];
+
 /*
  *
  * Private functions
@@ -151,6 +160,7 @@ static int
 parse_options(int argc, char **argv)
 {
     int tmp;
+    int opt_show_config = 0;
 
     for (;;) {
         int ch = getopt_long(argc, argv, short_options, long_options, NULL);
@@ -246,17 +256,20 @@ parse_options(int argc, char **argv)
 	    exit(EXIT_SUCCESS);
 	    break;
 	case 'C':
-	    if (load_rcfiles() != SUCCESS) {
-		die(nmz_get_dyingmsg());
-	    }
-	    show_config();
-	    exit(EXIT_SUCCESS);
+	    opt_show_config = 1;
 	    break;
 	case 'o':
 	    stdio2file(optarg);
 	    break;
 	}
     } 
+    if (opt_show_config) {
+	if (load_rcfiles() != SUCCESS) {
+	    die(nmz_get_dyingmsg());
+	}
+	show_config();
+	exit(EXIT_SUCCESS);
+    }
 
     return optind;
 }
@@ -293,7 +306,7 @@ main(int argc, char **argv)
 	 * since 1.9.14, they are different and we cannot
 	 * use "namazu" command as CGI any longer.  
 	 */
-	printf(MSG_MIME_HEADER);
+	printf("%s %s" CRLF CRLF, MSG_MIME_HEADER, contenttype);
 	printf("You should use \"namazu.cgi\" instead of \"namazu\" command.");
 	exit(EXIT_FAILURE);
     } else if (argc == 1) {
