@@ -1,5 +1,5 @@
 /*
- * $Id: output.c,v 1.71 2000/04/04 07:38:59 masao Exp $
+ * $Id: output.c,v 1.80.4.2 2001/07/31 06:11:03 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -31,6 +31,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 #include "namazu.h"
 #include "libnamazu.h"
 #include "codeconv.h"
@@ -45,6 +48,7 @@
 #include "var.h"
 #include "idxname.h"
 #include "query.h"
+#include "system.h"
 
 static int htmlmode    = 0;
 static int cgimode     = 0;
@@ -68,6 +72,7 @@ static char template_suffix[BUFSIZE] = "normal"; /* suffix of NMZ.result.* */
  */ 
 static char emphasis_start_tag[BUFSIZE] = "<strong class=\"keyword\">";
 static char emphasis_end_tag[BUFSIZE]   = "</strong>";
+char contenttype[BUFSIZE] = "text/html";
 
 /*
  *
@@ -182,16 +187,16 @@ fputs_without_html_tag(const char *str, FILE *fp)
 	    continue;
 	}
 	if (f == 0) {
-	    if (nmz_strprefixcmp(str, "&lt;") == 0) {
+	    if (strncmp(str, "&lt;", strlen("&lt;")) == 0) {
 		buf[i++] = '<';
 		str += 3;
-	    } else if (nmz_strprefixcmp(str, "&gt;") == 0) {
+	    } else if (strncmp(str, "&gt;", strlen("&gt;")) == 0) {
 		buf[i++] = '>';
 		str += 3;
-	    } else if (nmz_strprefixcmp(str, "&amp;") == 0) {
+	    } else if (strncmp(str, "&amp;", strlen("&amp;")) == 0) {
 		buf[i++] = '&';
 		str += 4;
-	    } else if (nmz_strprefixcmp(str, "&quot;") == 0) {
+	    } else if (strncmp(str, "&quot;", strlen("&quot;")) == 0) {
 		buf[i++] = '"';
 		str += 5;
 	    } else {
@@ -314,13 +319,6 @@ load_nmz_result(const char *basedir)
 	return NULL;
     }
 
-    /* In case of suffix isn't equal to lang, we needs code conversion */
-    if (strcmp(lang_suffix, nmz_get_lang()) != 0) {
-	char *new = nmz_codeconv_external(buf); /* new is allocated in nmz_codeconv_external. */
-	free(buf);  /* Then we should free buf's memory */
-	buf = new;
-    }
-
     return buf;
 }
 
@@ -461,7 +459,7 @@ print_query(const char * qs, int w)
 {
     int foo = 0;
     while (*qs) {
-	if (nmz_strprefixcmp(qs, "whence=") == 0) {
+	if (strncmp(qs, "whence=", strlen("whence=")) == 0) {
 	    foo = 1;
 	    printf("whence=%d", w);
 	    for (qs += strlen("whence="); isdigit(*qs); qs++);
@@ -475,7 +473,7 @@ print_query(const char * qs, int w)
 }
 
 /*
- * Displayi page index.
+ * Display page index.
  */
 static void 
 print_page_index(int n)
@@ -483,9 +481,14 @@ print_page_index(int n)
     int i, max, whence;
     char *qs; /* QUERY_STRING */
     char *sn; /* SCRIPT_NAME  */
+    char *dn; /* DOCUMENT_NAME  */
 
     qs = nmz_getenv("QUERY_STRING");
     sn = nmz_getenv("SCRIPT_NAME");
+    dn = nmz_getenv("DOCUMENT_NAME");
+
+    if(dn == NULL || *dn == '\0') 
+        dn=sn;
 
     html_print(_("	<strong>Page:</strong> "));
 
@@ -497,7 +500,7 @@ print_page_index(int n)
 	if (is_htmlmode()) {
 	    if (i * max != whence) {
 		printf("<a href=\"");
-		fputs(sn, stdout);
+		fputs(dn, stdout);
 		fputc('?', stdout);
 		print_query(qs, i * max);
 		printf("\">");
@@ -614,11 +617,14 @@ print_msgfile(const char *fname) {
 	strcat(tmpfname, suffix);
 
 	buf = nmz_readfile(tmpfname); /* buf is allocated in nmz_readfile. */
+	if (buf == NULL) {
+	    die(nmz_get_dyingmsg());
+	}
 	/* In case of suffix isn't equal to lang, we need code conversion */
 	if (strcmp(suffix, nmz_get_lang()) != 0) {
             /* new is allocated in nmz_codeconv_external. */
 	    char *new = nmz_codeconv_external(buf); 
-	    free(buf);  /* Then we shoul free buf's memory */
+	    free(buf);  /* Then we should free buf's memory */
 	    buf = new;
 	}
 
@@ -667,7 +673,7 @@ print_result(NmzResult hlist, const char *query, const char *subquery)
 {
 
     if (is_htmlmode() && is_cgimode()) {
-	printf(MSG_MIME_HEADER);
+	printf("%s %s" CRLF CRLF, MSG_MIME_HEADER, contenttype);
     }
 
     if (is_htmlmode()) {
@@ -757,7 +763,7 @@ print_result(NmzResult hlist, const char *query, const char *subquery)
 void 
 print_default_page (void) {
     if (is_htmlmode()) {
-	printf(MSG_MIME_HEADER);
+	printf("%s %s" CRLF CRLF, MSG_MIME_HEADER, contenttype);
 	print_headfoot(NMZ.head, "", "");
 	print_msgfile(NMZ.body);
 	print_headfoot(NMZ.foot, "", "");
@@ -767,8 +773,8 @@ print_default_page (void) {
 void 
 set_emphasis_tags(const char *start_tag, const char *end_tag)
 {
-    strcpy(emphasis_start_tag, start_tag);
-    strcpy(emphasis_end_tag,   end_tag);
+    strncpy(emphasis_start_tag, start_tag, BUFSIZE);
+    strncpy(emphasis_end_tag,   end_tag, BUFSIZE);
 }
 
 char *
@@ -783,6 +789,12 @@ get_emphasis_tag_end(void)
     return emphasis_end_tag;
 }
 
+void
+set_contenttype(const char *str)
+{
+    strncpy(contenttype, str, BUFSIZE);
+}
+
 void 
 set_htmlmode(int mode)
 {
@@ -934,7 +946,7 @@ die(const char *fmt, ...)
     fflush(stderr);
 
     if (is_cgimode()) {
-	printf(MSG_MIME_HEADER);
+	printf("%s %s" CRLF CRLF, MSG_MIME_HEADER, "text/html");
 	printf(_("<h2>Error</h2>\n<p>"));
 	va_start(args, fmt);
 	vprintf(fmt, args);
