@@ -1,6 +1,6 @@
 /*
  * 
- * $Id: rcfile.c,v 1.23 2000/02/23 08:26:03 satoru Exp $
+ * $Id: rcfile.c,v 1.31 2001/02/26 08:39:54 baba Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -31,6 +31,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 #include "namazu.h"
 #include "libnamazu.h"
 #include "rcfile.h"
@@ -45,6 +48,7 @@
 #include "search.h"
 #include "idxname.h"
 #include "output.h"
+#include "score.h"
 
 /*
  * Default directory to place namazurc.
@@ -111,9 +115,15 @@ static enum nmz_stat process_rc_alias ( const char *directive, const StrList *ar
 static enum nmz_stat process_rc_replace ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_logging ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_scoring ( const char *directive, const StrList *args );
+static enum nmz_stat process_rc_doclength ( const char *directive, const StrList *args );
+static enum nmz_stat process_rc_freshness ( const char *directive, const StrList *args );
+static enum nmz_stat process_rc_urilength ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_lang ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_emphasistags ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_template ( const char *directive, const StrList *args );
+static enum nmz_stat process_rc_maxhit ( const char *directive, const StrList *args );
+static enum nmz_stat process_rc_maxmatch ( const char *directive, const StrList *args );
+static enum nmz_stat process_rc_contenttype ( const char *directive, const StrList *args );
 
 struct conf_directive {
     char *name;
@@ -131,9 +141,15 @@ static struct conf_directive directive_tab[] = {
     { "REPLACE",       2, 0, process_rc_replace },
     { "LOGGING",       1, 0, process_rc_logging },
     { "SCORING",       1, 0, process_rc_scoring },
+    { "SCORE_DOCLENGTH", 1, 0, process_rc_doclength },
+    { "SCORE_FRESHNESS", 1, 0, process_rc_freshness },
+    { "SCORE_URILENGTH", 1, 0, process_rc_urilength },
     { "LANG",          1, 0, process_rc_lang },
     { "EMPHASISTAGS",  2, 0, process_rc_emphasistags },
     { "TEMPLATE",      1, 0, process_rc_template },
+    { "MAXHIT",        1, 0, process_rc_maxhit },
+    { "MAXMATCH",      1, 0, process_rc_maxmatch },
+    { "CONTENTTYPE",   1, 0, process_rc_contenttype },
     { NULL,            0, 0, NULL }
 };
 
@@ -221,11 +237,34 @@ process_rc_scoring(const char *directive, const StrList *args)
 {
     char *arg1 = args->value;
 
-    if (strcasecmp(arg1, "TFIDF") == 0) {
-	nmz_set_tfidfmode(1);
-    } else if (strcasecmp(arg1, "SIMPLE") == 0) {
-	nmz_set_tfidfmode(0);
-    }
+    nmz_set_scoring(arg1);
+    return SUCCESS;
+}
+
+static enum nmz_stat
+process_rc_doclength(const char *directive, const StrList *args)
+{
+    char *arg1 = args->value;
+
+    nmz_set_doclength(arg1);
+    return SUCCESS;
+}
+
+static enum nmz_stat
+process_rc_freshness(const char *directive, const StrList *args)
+{
+    char *arg1 = args->value;
+
+    nmz_set_freshness(arg1);
+    return SUCCESS;
+}
+
+static enum nmz_stat
+process_rc_urilength(const char *directive, const StrList *args)
+{
+    char *arg1 = args->value;
+
+    nmz_set_urilength(arg1);
     return SUCCESS;
 }
 
@@ -262,6 +301,34 @@ process_rc_template(const char *directive, const StrList *args)
     return SUCCESS;
 }
 
+static enum nmz_stat
+process_rc_maxhit(const char *directive, const StrList *args)
+{
+    int arg1 = atoi(args->value);
+
+    nmz_set_maxhit(arg1);
+    return SUCCESS;
+}
+
+static enum nmz_stat
+process_rc_maxmatch(const char *directive, const StrList *args)
+{
+    int arg1 = atoi(args->value);
+
+    nmz_set_maxmatch(arg1);
+    return SUCCESS;
+}
+
+static enum nmz_stat
+process_rc_contenttype(const char *directive, const StrList *args)
+{
+    char *arg1 = args->value;
+
+    set_contenttype(arg1);
+
+    return SUCCESS;
+}
+
 /* 
  * Get the environment variable of NAMAZURC, NAMAZUCONF or
  * NAMAZUCONFPATH.  and return it. Original of this code is
@@ -506,10 +573,10 @@ parse_rcfile(const char *line, int lineno)
 	StrList *ptr;
 	int i;
 
-	printf("%4d: Directive:  [%s]\n", lineno, directive);
+	nmz_debug_printf("%4d: Directive:  [%s]\n", lineno, directive);
 
 	for (ptr = args, i = 1 ; ptr != NULL; i++) {
-	    printf("      Argument %d: [%s]\n", i, ptr->value);
+	    nmz_debug_printf("      Argument %d: [%s]\n", i, ptr->value);
 	    ptr = ptr->next;
 	}
     }
@@ -724,10 +791,13 @@ Logging:      %s\n\
 Lang:         %s\n\
 Scoring:      %s\n\
 Template:     %s\n\
+MaxHit:       %d\n\
+MaxMatch:     %d\n\
 EmphasisTags: %s\t%s\n\
 "), nmz_get_defaultidx(), nmz_is_loggingmode() ? "on" : "off",
            nmz_get_lang(), nmz_is_tfidfmode() ? "tfidf" : "simple",
 	   get_templatedir(), 
+	   nmz_get_maxhit(), nmz_get_maxmatch(),
 	   get_emphasis_tag_start(), get_emphasis_tag_end()
 	   );
 
