@@ -1,6 +1,7 @@
 /*
- * $Id: result.c,v 1.54 2000/02/20 01:41:38 satoru Exp $
+ * $Id: result.c,v 1.59.8.4 2001/07/12 07:28:34 takesako Exp $
  * 
+ * Copyright (C) 1989, 1990 Free Software Foundation, Inc.
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
@@ -24,9 +25,13 @@
  */
 #include <string.h>
 #include <stdlib.h>
+#include <ctype.h>
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 #include "namazu.h"
 #include "i18n.h"
 #include "util.h"
@@ -51,10 +56,11 @@ static int uridecode   = 1;   /* Decode  URI in results as default. */
  */
 
 static void commas ( char *str );
-static char * strcasestr ( const char *haystack, const char *needle );
+static char *my_strcasestr ( char *s1, char *s2 );
 static void replace_field ( struct nmz_data d, int counter, const char *field, char *result );
 static void encode_entity ( char *str );
 static void emphasize ( char *str );
+static int is_wordboundary ( char *str );
 static int is_urireplace ( void );
 static int is_uridecode ( void );
 
@@ -83,29 +89,35 @@ commas(char *numstr)
 
 /* 
  * Case-insensitive brute force search
- * with consideration for EUC encoding schemes.
- *
- * FIXME: EUC-JP dependent.
  */
+
 static char *
-strcasestr(const char *haystack, const char *needle)
+my_strcasestr (s1, s2)
+     char *s1;
+     char *s2;
 {
-    int n = strlen(needle);
-    int euc_mode = 0;
+    int i;
+    char *p1;
+    char *p2;
+    char *s = s1;
+    int ja_mode;
 
-    if (nmz_is_lang_ja()) {
-	euc_mode = 1;
-    }
+    ja_mode = nmz_is_lang_ja ();
 
-    for (; *haystack != '\0'; haystack++) {
-	if (strncasecmp(haystack, needle, n) == 0) {
-	    return (char *)haystack;  /* cast for avoiding warning. */
-	}
-	if (euc_mode && nmz_iseuc(*haystack)) {
-	    haystack++;
+    for (p2 = s2, i = 0; *s; p2 = s2, i++, s++) {
+	for (p1 = s; *p1 && *p2 && (_nmz_tolower(*p1) == _nmz_tolower(*p2)); p1++, p2++)
+	    ;
+	if (!*p2)
+	    break;
+	if (ja_mode && (nmz_iseuc(*s) || nmz_iseuc_kana1st(*s))) {
+	    i++;
+	    if (!*(++s)) break;
 	}
     }
-    return NULL;
+    if (!*p2)
+	return s1 + i;
+
+    return 0;
 }
 
 static void 
@@ -206,18 +218,30 @@ emphasize(char *str)
 	keylen = strlen(key);
 
 	do {
-	    ptr = strcasestr(ptr, key);
+	    ptr = my_strcasestr(ptr, key);
 	    if (ptr != NULL) {
-		memmove(ptr + 2, ptr, strlen(ptr) + 1);
-		memmove(ptr + 1, ptr + 2, keylen);
-		*ptr = EM_START_MARK;
-		*(ptr + keylen + 1) = EM_END_MARK;
-		ptr += 2;
+              if ((ptr == str || is_wordboundary(ptr - 1))
+                  && keylen && is_wordboundary(ptr + keylen - 1)){
+                memmove(ptr + 2, ptr, strlen(ptr) + 1);
+                memmove(ptr + 1, ptr + 2, keylen);
+                *ptr = EM_START_MARK;
+                *(ptr + keylen + 1) = EM_END_MARK;
+                ptr += 2;
+              }
+              ptr += keylen;
 	    }
 	} while (ptr != NULL);
     }
 }
 
+static int
+is_wordboundary(char *p)
+{
+  if (isalpha(*p) && isalpha(*(p + 1))) return 0;
+  if (isdigit(*p) && isdigit(*(p + 1))) return 0;
+  return 1;
+}
+
 static int 
 is_urireplace(void)
 {
